@@ -17,7 +17,7 @@ parser.on('packet', function(packet) {
   // } 
 })
  
-parser.parse(new Buffer([
+parser.parse(Buffer.from([
   48, 10, // Header (publish) 
   0, 4, // Topic length 
   116, 101, 115, 116, // Topic (test) 
